beout
=====

``beout`` is a library for easily generating beautiful output for
long-running processes. It was originally conceived as part of
improving the usability of internal tools at Prezi.

Example
-------

[`example/example.py`](example/example.py) provides a full-fledged
example of all the features. The output looks like this:

|Example screencast|

.. |Example screencast| image:: https://raw.githubusercontent.com/abesto/beout/master/example/example.gif

